@@ -60,16 +60,16 @@ function _aws_cdk_aws_certificatemanager_CfnCertificateProps(p) {
 }
 function _aws_cdk_aws_certificatemanager_DnsValidatedCertificate(p) {
 }
+function _aws_cdk_aws_certificatemanager_CertificateValidation(p) {
+}
 function _aws_cdk_aws_certificatemanager_CfnAccount(p) {
 }
 function _aws_cdk_aws_certificatemanager_CfnAccount_ExpiryEventsConfigurationProperty(p) {
 }
-function _aws_cdk_aws_certificatemanager_CertificateValidation(p) {
+function _aws_cdk_aws_certificatemanager_Certificate(p) {
 }
 function _aws_cdk_aws_certificatemanager_PrivateCertificate(p) {
 }
-function _aws_cdk_aws_certificatemanager_Certificate(p) {
-}
 function _aws_cdk_aws_certificatemanager_CfnCertificate(p) {
 }
 function _aws_cdk_aws_certificatemanager_CfnCertificate_DomainValidationOptionProperty(p) {
@@ -89,5 +89,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_certificatemanager_ValidationMethod, _aws_cdk_aws_certificatemanager_PrivateCertificateProps, _aws_cdk_aws_certificatemanager_CfnAccountProps, _aws_cdk_aws_certificatemanager_ICertificate, _aws_cdk_aws_certificatemanager_DnsValidatedCertificateProps, _aws_cdk_aws_certificatemanager_CertificateProps, _aws_cdk_aws_certificatemanager_CertificationValidationProps, _aws_cdk_aws_certificatemanager_CfnCertificateProps, _aws_cdk_aws_certificatemanager_DnsValidatedCertificate, _aws_cdk_aws_certificatemanager_CfnAccount, _aws_cdk_aws_certificatemanager_CfnAccount_ExpiryEventsConfigurationProperty, _aws_cdk_aws_certificatemanager_CertificateValidation, _aws_cdk_aws_certificatemanager_PrivateCertificate, _aws_cdk_aws_certificatemanager_Certificate, _aws_cdk_aws_certificatemanager_CfnCertificate, _aws_cdk_aws_certificatemanager_CfnCertificate_DomainValidationOptionProperty };
+module.exports = { print, _aws_cdk_aws_certificatemanager_ValidationMethod, _aws_cdk_aws_certificatemanager_PrivateCertificateProps, _aws_cdk_aws_certificatemanager_CfnAccountProps, _aws_cdk_aws_certificatemanager_ICertificate, _aws_cdk_aws_certificatemanager_DnsValidatedCertificateProps, _aws_cdk_aws_certificatemanager_CertificateProps, _aws_cdk_aws_certificatemanager_CertificationValidationProps, _aws_cdk_aws_certificatemanager_CfnCertificateProps, _aws_cdk_aws_certificatemanager_DnsValidatedCertificate, _aws_cdk_aws_certificatemanager_CertificateValidation, _aws_cdk_aws_certificatemanager_CfnAccount, _aws_cdk_aws_certificatemanager_CfnAccount_ExpiryEventsConfigurationProperty, _aws_cdk_aws_certificatemanager_Certificate, _aws_cdk_aws_certificatemanager_PrivateCertificate, _aws_cdk_aws_certificatemanager_CfnCertificate, _aws_cdk_aws_certificatemanager_CfnCertificate_DomainValidationOptionProperty };
 module.exports.DeprecationError = DeprecationError;
