@@ -110,26 +110,14 @@ const requestCertificate = async function (requestId, domainName, subjectAlterna
 
   console.log('Waiting for ACM to provide DNS records for validation...');
 
-  let records;
-  for (let attempt = 0; attempt < maxAttempts && !records; attempt++) {
+  let records = [];
+  for (let attempt = 0; attempt < maxAttempts && !records.length; attempt++) {
     const { Certificate } = await acm.describeCertificate({
       CertificateArn: reqCertResponse.CertificateArn
     }).promise();
-    const options = Certificate.DomainValidationOptions || [];
-    // Ensure all records are ready; there is (at least a theory there's) a chance of a partial response here in rare cases.
-    if (options.length > 0 && options.every(opt => opt && !!opt.ResourceRecord)) {
-      // some alternative names will produce the same validation record
-      // as the main domain (eg. example.com + *.example.com)
-      // filtering duplicates to avoid errors with adding the same record
-      // to the route53 zone twice
-      const unique = options
-        .map((val) => val.ResourceRecord)
-        .reduce((acc, cur) => {
-          acc[cur.Name] = cur;
-          return acc;
-        }, {});
-      records = Object.keys(unique).sort().map(key => unique[key]);
-    } else {
+
+    records = getDomainValidationRecords(Certificate);
+    if (!records.length) {
       // Exponential backoff with jitter based on 200ms base
       // component of backoff fixed to ensure minimum total wait time on
       // slow targets.
@@ -137,19 +125,128 @@ const requestCertificate = async function (requestId, domainName, subjectAlterna
       await sleep(random() * base * 50 + base * 150);
     }
   }
-  if (!records) {
+  if (!records.length) {
     throw new Error(`Response from describeCertificate did not contain DomainValidationOptions after ${maxAttempts} attempts.`)
   }
 
-
   console.log(`Upserting ${records.length} DNS records into zone ${hostedZoneId}:`);
 
+  await commitRoute53Records(route53, records, hostedZoneId);
+
+  console.log('Waiting for validation...');
+  await acm.waitFor('certificateValidated', {
+    // Wait up to 9 minutes and 30 seconds
+    $waiter: {
+      delay: 30,
+      maxAttempts: 19
+    },
+    CertificateArn: reqCertResponse.CertificateArn
+  }).promise();
+
+  return reqCertResponse.CertificateArn;
+};
+
+/**
+ * Deletes a certificate from AWS Certificate Manager (ACM) by its ARN.
+ * If the certificate does not exist, the function will return normally.
+ *
+ * @param {string} arn The certificate ARN
+ */
+const deleteCertificate = async function (arn, region, hostedZoneId, route53Endpoint, cleanupRecords) {
+  const acm = new aws.ACM({ region });
+  const route53 = route53Endpoint ? new aws.Route53({ endpoint: route53Endpoint }) : new aws.Route53();
+  if (waiter) {
+    // Used by the test suite, since waiters aren't mockable yet
+    route53.waitFor = acm.waitFor = waiter;
+  }
+
+  try {
+    console.log(`Waiting for certificate ${arn} to become unused`);
+
+    let inUseByResources;
+    let records = [];
+    for (let attempt = 0; attempt < maxAttempts; attempt++) {
+      const { Certificate } = await acm.describeCertificate({
+        CertificateArn: arn
+      }).promise();
+
+      if (cleanupRecords) {
+        records = getDomainValidationRecords(Certificate);
+      }
+      inUseByResources = Certificate.InUseBy || [];
+
+      if (inUseByResources.length || !records.length) {
+        // Exponential backoff with jitter based on 200ms base
+        // component of backoff fixed to ensure minimum total wait time on
+        // slow targets.
+        const base = Math.pow(2, attempt);
+        await sleep(random() * base * 50 + base * 150);
+      } else {
+        break;
+      }
+    }
+
+    if (inUseByResources.length) {
+      throw new Error(`Response from describeCertificate did not contain an empty InUseBy list after ${maxAttempts} attempts.`)
+    }
+    if (cleanupRecords && !records.length) {
+      throw new Error(`Response from describeCertificate did not contain DomainValidationOptions after ${maxAttempts} attempts.`)
+    }
+
+    console.log(`Deleting certificate ${arn}`);
+
+    await acm.deleteCertificate({
+      CertificateArn: arn
+    }).promise();
+
+    if (cleanupRecords) {
+      console.log(`Deleting ${records.length} DNS records from zone ${hostedZoneId}:`);
+
+      await commitRoute53Records(route53, records, hostedZoneId, 'DELETE');
+    }
+
+  } catch (err) {
+    if (err.name !== 'ResourceNotFoundException') {
+      throw err;
+    }
+  }
+};
+
+/**
+ * Retrieve the unique domain validation options as records to be upserted (or deleted) from Route53.
+ *
+ * Returns an empty array ([]) if the domain validation options is empty or the records are not yet ready.
+ */
+function getDomainValidationRecords(certificate) {
+  const options = certificate.DomainValidationOptions || [];
+  // Ensure all records are ready; there is (at least a theory there's) a chance of a partial response here in rare cases.
+  if (options.length > 0 && options.every(opt => opt && !!opt.ResourceRecord)) {
+    // some alternative names will produce the same validation record
+    // as the main domain (eg. example.com + *.example.com)
+    // filtering duplicates to avoid errors with adding the same record
+    // to the route53 zone twice
+    const unique = options
+      .map((val) => val.ResourceRecord)
+      .reduce((acc, cur) => {
+        acc[cur.Name] = cur;
+        return acc;
+      }, {});
+    return Object.keys(unique).sort().map(key => unique[key]);
+  }
+  return [];
+}
+
+/**
+ * Execute Route53 ChangeResourceRecordSets for a set of records within a Hosted Zone,
+ * and wait for the records to commit. Defaults to an 'UPSERT' action.
+ */
+async function commitRoute53Records(route53, records, hostedZoneId, action = 'UPSERT') {
   const changeBatch = await route53.changeResourceRecordSets({
     ChangeBatch: {
       Changes: records.map((record) => {
-        console.log(`${record.Name} ${record.Type} ${record.Value}`)
+        console.log(`${record.Name} ${record.Type} ${record.Value}`);
         return {
-          Action: 'UPSERT',
+          Action: action,
           ResourceRecordSet: {
             Name: record.Name,
             Type: record.Type,
@@ -173,66 +270,7 @@ const requestCertificate = async function (requestId, domainName, subjectAlterna
     },
     Id: changeBatch.ChangeInfo.Id
   }).promise();
-
-  console.log('Waiting for validation...');
-  await acm.waitFor('certificateValidated', {
-    // Wait up to 9 minutes and 30 seconds
-    $waiter: {
-      delay: 30,
-      maxAttempts: 19
-    },
-    CertificateArn: reqCertResponse.CertificateArn
-  }).promise();
-
-  return reqCertResponse.CertificateArn;
-};
-
-/**
- * Deletes a certificate from AWS Certificate Manager (ACM) by its ARN.
- * If the certificate does not exist, the function will return normally.
- *
- * @param {string} arn The certificate ARN
- */
-const deleteCertificate = async function (arn, region) {
-  const acm = new aws.ACM({ region });
-
-  try {
-    console.log(`Waiting for certificate ${arn} to become unused`);
-
-    let inUseByResources;
-    for (let attempt = 0; attempt < maxAttempts; attempt++) {
-      const { Certificate } = await acm.describeCertificate({
-        CertificateArn: arn
-      }).promise();
-
-      inUseByResources = Certificate.InUseBy || [];
-
-      if (inUseByResources.length) {
-        // Exponential backoff with jitter based on 200ms base
-        // component of backoff fixed to ensure minimum total wait time on
-        // slow targets.
-        const base = Math.pow(2, attempt);
-        await sleep(random() * base * 50 + base * 150);
-      } else {
-        break
-      }
-    }
-
-    if (inUseByResources.length) {
-      throw new Error(`Response from describeCertificate did not contain an empty InUseBy list after ${maxAttempts} attempts.`)
-    }
-
-    console.log(`Deleting certificate ${arn}`);
-
-    await acm.deleteCertificate({
-      CertificateArn: arn
-    }).promise();
-  } catch (err) {
-    if (err.name !== 'ResourceNotFoundException') {
-      throw err;
-    }
-  }
-};
+}
 
 /**
  * Main handler, invoked by Lambda
@@ -262,7 +300,13 @@ exports.certificateRequestHandler = async function (event, context) {
         // If the resource didn't create correctly, the physical resource ID won't be the
         // certificate ARN, so don't try to delete it in that case.
         if (physicalResourceId.startsWith('arn:')) {
-          await deleteCertificate(physicalResourceId, event.ResourceProperties.Region);
+          await deleteCertificate(
+            physicalResourceId,
+            event.ResourceProperties.Region,
+            event.ResourceProperties.HostedZoneId,
+            event.ResourceProperties.Route53Endpoint,
+            event.ResourceProperties.CleanupRecords === "true",
+          );
         }
         break;
       default:
